compDist <-
function(HistA,HistB,method='MMD',sigma=NULL){


if (length(HistA)!=length(HistB)){
  stop('size of HistA and HistB are different')
}

Bins <- as.integer(names(HistA))
if (!identical(Bins,as.integer(names(HistB)))){
    stop('different Bins')
}


t1a <- proc.time();
if (method=='MMD'){
  # Draw positions from histograms
  pos1 <- rep(Bins,HistA)-min(Bins)
  pos2 <- rep(Bins,HistB)-min(Bins)
  temp <- max(c(pos1,pos2))
  pos1 <- pos1-1/2*temp
  pos2 <- pos2-1/2*temp
  if (any(pos2>sqrt(2*10^9))|any(pos1>sqrt(2*10^9))){
      warning('peak width exceeds sqrt(2*10^9): creates integer overflow ')
      message('Peak scaled down')
      pos1 <- pos1/10000
      pos2 <- pos2/10000
  }


  if (length(unique(pos1))<2||length(unique(pos2))<2){
    d <- list(method,NA,NA,NA,0)
    names(d) <- c('method','val','kernelsize','mdist','time')
    message('histograms empty')
      return(d)
  }

  XX <- as.matrix(c(pos1,pos2),ncol=1)
  labels <- c(rep(1,length(pos1)),rep(-1,length(pos2)))

  MMD <- mmd(XX,labels,sigma=sigma)
  #MMD <- list(0,0)
  #names(MMD)=c('biased','kernelsize')
  d <- list('MMD',MMD$biased,MMD$kernelsize,MMD$mdist,0)
  names(d) <- c('method','val','kernelsize','mdist','time')
  # unbiased[i] = MMD$unbiased;
} else if (method=='GMD'){
  gmd <- gmdp(HistA,HistB, labels=c("v1","v2"), pseudocount=0,sliding=FALSE, resolution=1)
  d <- list('GMD',gmd,0)
  names(d)=c('method','val','time')
} else if (method=='Pearson'){
  P <- cor(HistA,HistB)
  d <- list('Pearson',P,0)
  names(d) <- c('method','val','time')
}
d$time <- proc.time()[1]-t1a[1]


return(d)

}
