compHists <-
function(Reads, bin.length=20, boundary=200, save.file=FALSE, out.file){

  Pos.p <- Reads$Pos.p
  Pos.n <- Reads$Pos.n

  N <- names(Pos.p)
  if (!identical(N,names(Pos.n))){
    warning('different peaks considered for forward and reverse strand')
  }

  aa <- strsplit(N,':')
  S <- sapply(aa, function(a){strsplit(a[2], '-')})
  breaks <- lapply(S, function(a){seq(from=as.integer(a[1])-boundary, to=as.integer(a[2])+boundary, by=bin.length)})

  Counts.p <- vector("list", length(N))
  names(Counts.p) <- N
  Counts.n <- Counts.p
  Counts <- Counts.p
  Mids <- Counts.p

  for (i in 1:length(Pos.p)){
    if (length(Pos.p[[i]])==0){
      Counts.p[[i]] <- rep(0, length(breaks[[i]])-1)
      Mids[[i]] <- hist(breaks[[i]], breaks[[i]], plot=FALSE)$mids
    } else {
      P <- Pos.p[[i]][Pos.p[[i]]>min(breaks[[i]])&&Pos.p[[i]]<max(breaks[[i]])]
      h.pos <- hist(P, breaks=breaks[[i]], plot = FALSE)
      Counts.p[[i]] <- h.pos$counts
      Mids[[i]] <- h.pos$mids
    }
    if (length(Pos.n[[i]])==0){
      Counts.n[[i]] <- rep(0, length(breaks[[i]])-1)
    } else {
      P <- Pos.n[[i]][Pos.n[[i]]>min(breaks[[i]])&&Pos.n[[i]]<max(breaks[[i]])]
      h.neg <- hist(P, breaks=breaks[[i]], plot = FALSE)
      Counts.n[[i]] <- h.neg$counts

      if (!identical(Mids[[i]], h.neg$mids)){
        warning('something wrong with hist mid points')
      }
    }
    Counts[[i]] <- Counts.p[[i]]+Counts.n[[i]]
  }

  Hists <- list(Counts, Mids, Counts.p, Counts.n)
  names(Hists) <- c('Counts', 'Mids', 'Counts.p', 'Counts.n')

  if (save.file){
    message("writing to file", out.file, "\n")
    save(Hists, file=out.file)
  }
  return(Hists)
}
