getNormFactors <-
function(DBA, method='DESeq', SampleIDs=NULL, Usefiltered=TRUE, PeakIDs=NULL, overWrite=FALSE){

  if (!is.element('MD',names(DBA))){
    stop('No histograms provided, call MD.countHists first')
  }
  MD <- DBA$MD
  samples <- DBA$samples
  Counts <- MD$RawTotalCounts
  message('Computing Scaling factor according to ', method, ' normalization method')
  
  if (is.null(SampleIDs)){
    SampleIDs <- samples$SampleID
    message('Using all Samples: nSamples = ', length(SampleIDs))
  } else {
    message('Using subset of samples: nSamples = ', length(SampleIDs),' (of ', length(samples$SampleID),')')
  }
  message('Samples:')
  print(SampleIDs)

  Sample.idx <- sapply(SampleIDs,function(id){ix=which(samples$SampleID==id)})

  if (Usefiltered & is.element('Filter',names(MD))){
    message('Using filtered Peaks')
    filtids <- MD$Filter$FiltPeakIds
  } else{
    message('Using unfiltered Peaks')
    filtids <- seq(1,nrow(Counts))
  }
  if (is.null(PeakIDs)){
    PeakIDs <- filtids
  } else{
    PeakIDs <- intersect( PeakIDs,  filtids)
    message('Using subset of all Peaks for normalization.')
  }
  message('nPeaks = ',length(PeakIDs),' (of ',nrow(Counts),')')
  
  
  Counts <- Counts[PeakIDs,Sample.idx]

  if (identical(method,'DESeq')){
    loggeomeans <- apply(log(Counts),1,mean)
    sfs <- apply(Counts, 2, function(cnts) (log(cnts) - loggeomeans)[is.finite(loggeomeans)])
    factors <- exp(apply(sfs,2,median))
  } else {
    stop('normalization message not yet implemented')
  }
  
  #Preparing output
  NFname <- paste(SampleIDs, collapse = ',')
  factors <- list(factors)
  names(factors) <- NFname
  if (any(names(MD)=='NormFactors')){
    if (is.element(method,names(MD$NormFactor))){
      if (!overWrite){
        message('NormFactors already exist')
        message('Old Factors are kept. Execution stopped')
        return
        # message('appending NormFactors')
        # MD$NormFactors[[method]] <- c(MD$NormFactors[[method]],factors)
      }else{
        message('overwriting NormFactors')
        MD$NormFactors[[method]] <- factors
      }
    } else{
      MD$NormFactors[[method]] <- factors
    }
  } else {
    MD$NormFactors[[method]] <- factors
  }

  #normalize total counts
  NormCounts <- matrix(0,nrow=nrow(MD$RawTotalCounts),ncol=ncol(MD$RawTotalCounts))
  colnames(NormCounts) <- colnames(MD$RawTotalCounts)
  for (i in 1:length(Sample.idx)){
    NormCounts[,Sample.idx[i]] <- MD$RawTotalCounts[,Sample.idx[i]]/factors[[1]][i]
  }
  if (any(names(MD)=='NormTotalCounts')){
    message('NormTotalCounts already exist')
    
    if (overWrite){
      message('overwriting NormTotalCounts')
      MD$NormTotalCounts <- NormCounts
    }else{
      message('NormTotalCounts not updated (set overWrite=TRUE)')
    }
  } else{
    message('appending NormTotalCounts')
    MD$NormTotalCounts <- NormCounts
  }
  message('Determined Factors:')
  print(factors)
  
  
  DBA$MD <- MD
  return(DBA)
}
