getPeakProfiles <-
function(DBA, Peaks, bin.length=20, keep.extra = FALSE,
                            draw.on=TRUE, save.files=FALSE, use.old=TRUE,
                            out.dir='.',run.parallel=TRUE){
  ## cluster stuff
  if (run.parallel){
    NCPUs <- detectCores()
    cl <- makeCluster(NCPUs)
  }

  chroms <- DBA$chrmap

  numChips <- nrow(DBA$samples)
  chips <- unique(DBA$samples$bamReads)
  inputs <- DBA$samples$bamControl
  inputs <- unique(inputs[!is.na(inputs)])
  todo <- unique(c(chips, inputs))

  message('Peak length statistics:')
  #print(summary(width(Peaks)))
  FNS <- lapply(todo, function(FN){fn <- unlist(strsplit(FN,'/')); fn <- fn[length(fn)]})
  FNS <- lapply(FNS, function(FN){fn <- unlist(strsplit(FN,'.bam')); fn <- fn[1]})
  Hists.Raw <- vector("list", length(todo))

  numPeaks <- length(Peaks)

  for (i in 1:length(todo)){
    out.file <- paste(out.dir, FNS[[i]], '.Rdata', sep='')
    if (use.old && file.exists(out.file)){

      message("loading old file: ", out.file, "\n")
      load(file = out.file)
    } else {

      message('loading reads from file: ', todo[i])
      Pos.p <- vector("list", numPeaks)
      Pos.n <- Pos.p
      peak.id <- 0
      if (run.parallel){
        cl.idx <-  clusterSplit(cl,1:length(chroms))
        chrsplt <- lapply(cl.idx, function(id) chroms[id])
        
        r <- clusterApplyLB(cl,chrsplt, getReadsWrapper,Peaks,todo[[i]])
        
        Reads <- sortReads(r,Peaks)
      } else {
        Reads <- getReadsWrapper(chroms,Peaks,todo[[i]])
      }


      # CORRECT FOR SHIFT BETWEEN +/-STRAND
      message('correcting for strand shift')
      Idx <- getPeakIds4shift(Reads, draw.on, fname = FNS[[i]])
      if (length(Idx)==0){
        message('can\'t determine shift between forward and reverse strand. Not enough peaks!')
        shift <- 0
      } else{
        shift <- getShift(Reads, Idx,draw.on = draw.on, fname = FNS[[i]])
        Reads <- shiftReads(Reads, shift)
      }
      message('computing histograms with bin.length ', bin.length, ' bp')
      Hists <- compHists(Reads, bin.length = bin.length)
      Hists$Meta$shift <- shift
      #Hists$Meta$shift.Idx <- Idx
      Hists$Meta$bin.length <- bin.length
      if (save.files){
        out.file <- paste(out.dir, FNS[[i]], '.Rdata', sep='')
        message("writing to file", out.file, "\n")
        save(Reads, Hists, file = out.file)
      }
    }# end else (file does not exist yet)
    Hists.Raw[[i]] <- Hists
    names(Hists.Raw)[i] <- FNS[[i]]
  }# end loop over files

  message('Computing Count Matrix (nSamples x nBins) for each peak')
  PeakRawHists <- compPeakMatrix(Hists.Raw)
  message('Computing total counts for each sample and each peak')
  RawTotalCounts <- compPeakTotalCounts(PeakRawHists)

  # prepare output
  DBA$MD$PeakRawHists <- PeakRawHists
  DBA$MD$RawTotalCounts <- RawTotalCounts
  if (keep.extra){
    DBA$MD$RawHists <- Hists.Raw
  }
  if (save.files){
    out.file <- paste(out.dir, 'AllSamples.Rdata', sep='')
    message("writing to file", out.file, "\n")
    save(DBA,file = out.file)
  }
  if (run.parallel){
    stopCluster(cl)
  }
  return(DBA)
}
