getReads <-
function(Peaks, chrom, bam.file, save.file = FALSE, out.file){

  header <- scanBamHeader(bam.file)
  if (length(which(names(header[[1]]$targets)==chrom))==0) {
    message('no reads found mapping to ', chrom)
    chrchrom <- paste('chr', chrom, sep='')
    rmchrchrom <- unlist(strsplit(chrom, 'chr'))[2]
    if (length(which(names(header[[1]]$targets)==chrchrom))>0) {
      message('changing ', chrom, ' to ', chrchrom)
      chrom <- chrchrom
    } else if (length(which(names(header[[1]]$targets)==rmchrchrom))>0) {
      message('changing ', chrom, ' to ', rmchrchrom)
      chrom <- rmchrchrom
    } else {
      warning('no reads found on ',chrom)
      Names <- vector('list', nrow(Peaks))
      for (i in 1:nrow(Peaks)){
        Names[i] <- paste(Peaks[i,1], ':', Peaks[i,2], '-', Peaks[i,3], sep='')
      }
      Pos.p <- vector('list', nrow(Peaks))
      names(Pos.p) <- Names
      Pos.n <- Pos.p
      Reads <- list(Pos.p, Pos.n)
      names(Reads) <- c('Pos.p', 'Pos.n')
      return(Reads)
    }
  }

  which <- RangesList(IRanges(Peaks[,2], Peaks[,3]))
  names(which) <- c(chrom)
  what <- c("rname", "strand", "pos")
  param <- ScanBamParam(which=which, what=what)

  bam <- scanBam(bam.file, param=param)

  # Positive Strand
  Pos.p <- lapply(bam, function(bam){bam$pos[bam$strand=='+']})
  # Negative Strand
  Pos.n <- lapply(bam, function(bam){bam$pos[bam$strand=='-']})

  Reads <- list(Pos.p, Pos.n)
  names(Reads) <- c('Pos.p', 'Pos.n')
  if (save.file){
    message("writing to file", out.file, "\n")
    save(Reads, file=out.file)
  }

  return(Reads)
}
