mmd <-
function(X,labels,sigma=NULL) {

  poslabels <- which(labels==1);
  neglabels <- which(labels==-1);

  if (length(poslabels)==0 || length(neglabels)==0){
    stop('kmd(): each sample should have at least one observation ');
  }

  # KERNEL

  # RULE OF THUMB to determine Kernel width
  # calculates the kernel matrix and estimate sigma

  x <- as.matrix(X[poslabels,],nrow=length(poslabels));
  y <- as.matrix(X[neglabels,],nrow=length(neglabels));

  ## Kxx
  G <- x%*%t(x);
  L <- ncol(G);
  nor <- rep(G[seq(1,L^2,L+1)],L);
  Kxx <- -2*G +matrix(nor, nrow=L,byrow=TRUE)+matrix(nor, nrow=L)
  rm(ls='G', 'L', 'nor')

  ## Kyy
  G <- y%*%t(y);
  L <- ncol(G);
  nor <- rep(G[seq(1,L^2,L+1)],L);
  Kyy <- -2*G +matrix(nor, nrow=L,byrow=TRUE)+matrix(nor, nrow=L)
  rm(ls='G', 'L', 'nor')

  ## Kxy
  G <- x%*%t(y);
  Ly <- ncol(G);
  Lx <- nrow(G);
  norx <- rep(rowSums(x*x),Ly);
  nory <- rep(rowSums(y*y),Lx);
  Kxy <- t(-2*G +matrix(norx, nrow=Lx)+matrix(nory, nrow=Lx,byrow=TRUE))
  rm(ls='G', 'Lx','Ly', 'norx','nory')


  #now get the median distance
  mdist <- median(Kxy[Kxy!=0]);
  mdist <- sqrt(mdist/2);
  if (is.null(sigma)){
    sigma <- mdist;
    if (sigma ==0){
      sigma <- 1;}
  }
  #apply RBF
  Kxx <- exp(-1/2/sigma^2 * Kxx);
  Kyy <- exp(-1/2/sigma^2 * Kyy);
  Kxy <- exp(-1/2/sigma^2 * Kxy);

  rm('x' ,'y')

  # fprintf('Using RBF kernel with sigma=#1.2f\n',kernelsize);

  ############
  # calculates MMD

  m <- nrow(Kxx);
  n <- nrow(Kyy);

  N <- max(m,n);
  M <- min(m,n);


  #Kxx
  sumKxx <- sum(Kxx);
  if (m!=n){
    sumKxx_M <- sum(sum(Kxx[1:M,1:M]));
  } else {
    sumKxx_M <- sumKxx;
  }
  dgxx <- Kxx[seq(1,m^2,m+1)];

  sumKxxnd <- sumKxx - sum(dgxx); #no diags

  # R = max(dgxx); #upper bound on kernel, should be one
  # R_M = max(dgxx[1:M]);

  # h_u = colSums(Kxx[1:M,1:M]) - dgxx[1:M]; #one sided sum

  #Kyy
  sumKyy <- sum(Kyy);
  if (m!=n){
    sumKyy_M <- sum(sum(Kyy[1:M,1:M]));
  } else {
    sumKyy_M <- sumKyy;
  }

  dgyy <- Kyy[seq(1,n^2,n+1)];

  sumKyynd <- sumKyy - sum(dgyy); #no diags

  # R = max(R,max(dgyy)); #upper bound on kernel, should be one
  # R_M = max(R,max(dgyy[1:M]));

  # h_u = h_u + colSums(Kyy[1:M,1:M]) - dgyy[1:M]; #one sided sum


  #Kxy
  sumKxy <- sum(Kxy);
  if (m!=n){
    sumKxy_M <- sum(sum(Kxy[1:M,1:M]));
  } else {
    sumKxy_M <- sumKxy;
  }

  # dg = Kxy[seq(1,nrow(Kxy)*M,nrow(Kxy)+1)]; #up to M only

  # h_u = h_u -  colSums(Kxy[1:M,1:M]) - colSums(t(Kxy[1:M,1:M])) + 2*dg; #one sided sum


  #compute MMDs
  #corrolary 11 (biased)
  biased <- sqrt(sumKxx/(m*m) +  sumKyy/(n * n) - 2/m/n * sumKxy);

  #equation 14
  #only for m==n (=M) (unbiased)
  #unbiased = sum(h_u)/M/(M-1);
  #mmd=list(biased,unbiased,sigma)
  #names(mmd)=c('biased','unbiased','kernelsize')

  mmd <- list(biased,sigma,mdist)
  names(mmd) <- c('biased','kernelsize','mdist')
  return(mmd)

}
