plotHistDists <-
function(DBA, method='MMD', group1, group2, 
                          field4X = 'NormTotalCounts',
                          bUsePval=FALSE,pnames="combined", thresh=0.05,
                          save2file=FALSE,fn.pics,ftype=pdf,xlim=NULL,ylim=NULL){

  samples <- DBA$samples

  MD <- DBA$MD
  DISTS <- MD$DISTS[[method]]

  if (identical(field4X,'PeakWidth')){
    Peaks <- dba.peakset(DBA,bRetrieve=TRUE)
    Ns <- width(Peaks)
    Counts=NULL
  } else {
    Counts <- MD[[field4X]]
  }
  
  if (bUsePval){
    sigred='Pvals'
  }else sigred='FDR'
  
  if (is.element(sigred,names(MD))){
    Pvals <- MD[[sigred]][[method]]
  } else Pvals <- NULL

  compNames <- colnames(DISTS)

  within1 <- determineGroupComps(group1,type='within')
  within2 <- determineGroupComps(group2,type='within')
  between <- determineGroupComps(group1,group2,type='between')

  #### get total counts
  temp <- c(within1,within2,between)
  temp <- unique(unlist(strsplit(temp,' vs ')))
  SampleIDs <- which(is.element(samples$SampleID,temp))
  
  if (!is.null(Counts)){
    Counts <- Counts[,SampleIDs]
    Ns <- rowMeans(Counts)
  }
  #Ns <- log10(Ns)
  #### get distances

  ids1 <- findComps(within1,compNames)
  ids2 <- findComps(within2,compNames)
  ids3 <- findComps(between,compNames)

  W1 <- as.matrix(DISTS[,ids1])
  W2 <- as.matrix(DISTS[,ids2])
  B <- as.matrix(DISTS[,ids3])

  #### get pvals
  if (!is.null(Pvals)){
    if (!is.null(pnames)){
      idx <- which(colnames(Pvals)==pnames)
    } else idx <- 1
    pvals <- Pvals[,idx]
    message('using ', sigred, ' from ',colnames(Pvals)[idx])
    Idx <- which(pvals<thresh)
  }



  #### plotting
  if (is.null(xlim)){
    if (is.element('Filter',names(MD))){
      xlim <- c(min(Ns[!is.infinite(Ns)]),max(Ns[MD$Filter$FiltPeakIds]))
    } else {
      xlim <- c(min(Ns[!is.infinite(Ns)]),max(Ns))
    }
  }
  if (is.null(ylim)){
    yy <- cbind(B,W1,W2)
    ylim <- c(min(yy[!is.na(yy)]),max(cbind(B,W1,W2),na.rm = TRUE))
  }
  
  # xlab <- paste(field4X ,' (average of ', paste(temp,collapse=', '), ')',sep='')
  if (identical(field4X,'NormTotalCounts')){
    xlab <- paste('mean of normalized counts')
  } else if (identical(field4X,'PeakWidth')){
    xlab <- 'peak width [bp]'
  } else {
    xlab <- paste('mean counts')
  }
  
  ylab <- paste(method, '-based distance between profiles',sep='')
  main <- paste(paste(group1,collapse=','),' vs ',paste(group2,collapse=', '),' (nPeaks = ',length(Ns),')',sep='')
  if (!is.null(Pvals)){
    leg3 <- paste(sigred,'<', thresh, ': n = ',length(Idx),sep='')

   #leg3 <- paste(sigred,'<', thresh, ' (',colnames(Pvals)[idx],'): n = ',length(Idx),sep='')
  }else{
    leg3 <- ''
  }

  if (method=='Pearson'){
    position <- "bottomright"
  }  else if (method=='MMD'){
    position <- "topright"
  } else{
    position <- "topleft"
  }

  plot(Ns,rowMeans(B),xlab=xlab,ylab=ylab,main=main,xlim=xlim,ylim=ylim,col = "blue",pch =20, cex = 0.6)#,log='x')
  #smoothScatter(Ns,rowMeans(B),xlab=xlab,ylab=ylab,main=main,xlim=xlim,ylim=ylim,col = "blue")
  if (is.null(within1)&&is.null(within2)){
    message('no replicates given for within group variance')
  } else {
    points(Ns,rowMeans(cbind(W1,W2)),pch=4,cex=0.6)
  }
  if (!is.null(Pvals)&&length(Idx)>0){
    points(Ns[Idx],rowMeans(B[Idx,,drop=F]),col='red',pch=21,cex=0.6)
  }
  legend(position,pch=c(20,4,21),pt.cex=c(1,1,1),col=c('blue','black','red'),c('between groups','within groups',leg3))
  grid()
  #legend(position,fill=c('blue','white','white'),border=c('black','white','white'),pch=c(20,4,21),pt.cex=c(0.2,0.6,0.8),col=c('black','black','red'),c('between groups','within groups',paste('p<0.05 (',colnames(Pvals)[idx],' )')))


###save to file
  if (save2file){
    #for (i in 1:length(ftypes)){
     # if (ftypes[i])
     # fn.pic=paste(fn.pics,'')

      ftype(fn.pics)
      
      message('saving image to ',fn.pics)
      plot(Ns,rowMeans(B),xlab=xlab,ylab=ylab,main=main,xlim=xlim,ylim=ylim,col = "blue",pch =20, cex = 0.6,xlog=log,cex.lab=1.6,cex.axis=1.3,cex.main=1.6)
                                        #smoothScatter(Ns,rowMeans(B),xlab=xlab,ylab=ylab,main=main,xlim=xlim,ylim=ylim,col = "blue")
      if (is.null(within1)&&is.null(within2)){
        message('no replicates given for within group variance')
      } else {
        points(Ns,rowMeans(cbind(W1,W2)),pch=4,cex=0.6)
      }
      if (!is.null(Pvals)&&length(Idx)>0){
        points(Ns[Idx],rowMeans(B[Idx,,drop=F]),col='red',pch=21,cex=0.6)
      }
      legend(position,pch=c(20,4,21),pt.cex=c(1,1,1),col=c('blue','black','red'),c('between groups','within groups',leg3))
      dev.off()
    #}
  }
}
