plotPeak <-
function(DBA,Peak.id,Sample.ids=NULL,NormMethod='DESeq',plot.input=TRUE,fieldname="PeakRawHists",save2file=FALSE,fn.pics){

  samples <- DBA$sample
  MD <- DBA$MD
  Peak <- MD[[fieldname]][Peak.id]
  PeakName <- names(Peak)

  Peak <- Peak[[1]]

  if (is.null(Sample.ids)){
    Sample.ids <- samples$SampleID
    Sample.idx <- 1:length(samples$SampleID)
  } else{
    Sample.idx <- sapply( Sample.ids,function(id){ix=which(samples$SampleID==id)})
  }
  SamplePeaks <- Peak[Sample.idx,]

  ##Normalization
  if (is.null(NormMethod)){
    message('No normalization factors applied')
    Factors <- rep(1,length(Sample.idx))
    ylab <- 'counts'
  } else {
    NormFactors <- MD$NormFactors[[NormMethod]][[1]]
    #check if factor is available for all relevant samples
    if (!all( is.element(rownames(SamplePeaks),names(NormFactors)))){

        tmp <- which(!is.element(rownames(SamplePeaks),names(NormFactors)))
      message('no normalization factor found for sample: ',rownames(SamplePeaks)[tmp])
      stop('check normalization factors')
    }
    Factors <- NormFactors[sapply(rownames(SamplePeaks),function(name){idx=which(name==names(NormFactors))})]
    ylab='normalized counts'
  }


  ##INPUT
  if (plot.input){
    inputs <- unique(samples$bamControl)
    inputs <- lapply(inputs,function(FN){fn=unlist(strsplit(FN,'/'));fn=fn[length(fn)]})
    inputs <- lapply(inputs,function(FN){fn=unlist(strsplit(FN,'.bam'));fn=fn[1]})
    input.idx <- sapply(inputs,function(id){ix=which(rownames(Peak)==id)})
    InputPeaks <- Peak[input.idx,, drop=FALSE]
    leg <- c(Sample.ids,inputs)
  } else{
    leg <- Sample.ids
  }



  nSamples <- length(Sample.ids)

  cols <- rainbow(nSamples)


  plot(colnames(SamplePeaks),SamplePeaks[1,]/Factors[1],t='l',col=cols[1],ylim=c(min(SamplePeaks),1.2*max(SamplePeaks)),ylab=ylab,xlab=PeakName)
  for (i in 2:nSamples){
    points(colnames(Peak),SamplePeaks[i,]/Factors[i],t='l',col=cols[i])
  }
  if (plot.input){
    for (i in 1:length(input.idx)){
      points(colnames(Peak),InputPeaks[i,],lty=2,t='l',col='black')
    }
  }
  legend("topleft",legend=leg,col=c(cols,'black'),lty=c(rep(1,nSamples),2))

  ###save to file
  if (save2file){
    message('saving image to ',fn.pics)
    pdf(fn.pics)
    plot(colnames(SamplePeaks),SamplePeaks[1,]/Factors[1],t='l',
         col=cols[1],ylim=c(min(SamplePeaks),1.2*max(SamplePeaks)),ylab=ylab,xlab=PeakName)
    for (i in 2:nSamples){
        points(colnames(Peak),SamplePeaks[i,]/Factors[i],t='l',col=cols[i])
    }
    if (plot.input){
        for (i in 1:length(input.idx)){
            points(colnames(Peak),InputPeaks[i,],lty=2,t='l',col='black')
        }
    }
    legend("topleft",legend=leg,col=c(cols,'black'),lty=c(rep(1,nSamples),2))

    dev.off()

  }

}
