\name{Cfp1Dists}
\docType{data}
\alias{Cfp1Dists}
\title{Example DBA object used to illustrate usage of the MMDiff package}

\description{The object contains a small subset of the CIP-Seq data sets
  generated to assess the link between the histone modification states
  of H3K4me3 with respect to the mediator proteins Cfp1 [1]. The data is
  available as part of ArrayExpress Experiment E-ERAD-79. For more
  details see the MMDiffBamSubset data package.
  
}

\usage{data(Cfp1Dists)}
\format{A DBA object containing the additional component MD.  A DBA
  object is an S3 object (class "DBA"), which is introduced with the
  DiffBind package and more information on this class can be found in
  the Diffbind vignette.
  
  The added field MD is a list containing the following elements:

  - RawTotalCounts: matrix of total counts per peak and sample
  (nPeaks x nSamples) 
  
  - PeakRawHists: list of length nPeaks, containing for each Peak a
  Matrix of histograms (nSamples x nbins). Note, as Peaks can vary in
  length, nbins may be different for each Peak.
  
  - NormFactors: Normalization factors    

  - NormTotalCounts: Normalized total counts
  
  - DISTS: containing distances computed for 'MMD','GMD' and
  'Pearson'. Each being a (nPeaks x 3) matrix containing in the first
  column the distances between pairs of peaks in the WT vs Null samples,
  in the second WT vs Resc and in the third Null vs Resc
}
\source{See the MMDiffBamSubset data package for more details.}

\references{
  [1] Clouaire T et al (2012). Cfp1 integrates both CpG
  content and gene activity for accurate H3K4me3 deposition in embryonic
  stem cells.  Genes Dev. August 1, 2012 26: 1714--1728 }

\keyword{datasets}

\seealso{
  \link[DiffBind]{dba},
  \link[DiffBind]{summary.DBA}
}
\examples{
  # The object has been generated using the following commands:
  ##### STEP1: load peak profiles and normalize
  
  data(Cfp1Profiles)

  Cfp1Norm <- getNormFactors(Cfp1Profiles)
  
  ##### STEP2: compute distances between histograms 

  Cfp1Dists <- compHistDists(Cfp1Norm,method='MMD', NormMethod='DESeq')
  
  Cfp1Dists <- compHistDists(Cfp1Dists,method='GMD', NormMethod='DESeq' )
  Cfp1Dists <- compHistDists(Cfp1Dists,method='Pearson',
  NormMethod='DESeq')
}