\name{Cfp1Profiles}
\docType{data}
\alias{Cfp1Profiles}
\title{Example DBA object used to illustrate usage of the MMDiff package}

\description{The object contains a small subset of the CIP-Seq data sets
  generated to assess the link between the histone modification states
  of H3K4me3 with respect to the mediator proteins Cfp1 in mouse
  [1]. The data is available as part of ArrayExpress Experiment
  E-ERAD-79. For more details see the MMDiffBamSubset data package.
  
}

\usage{data(Cfp1Profiles)}

\format{A DBA object containing the additional component MD.  A DBA
  object is an S3 object (class "DBA"), which is introduced with the
  DiffBind package and more information on this class can be found in
  the Diffbind vignette.
  
  The added field MD is a list containing the following elements:
  
  - RawTotalCounts: matrix of total counts per peak and sample
  (nPeaks x nSamples)
  
  - PeakRawHists: list of length nPeaks, containing for each Peak a
  Matrix of histograms (nSamples x nbins). Note, as Peaks can vary in
  length, nbins may be different for each Peak. 

} 
  
\source{See the MMDiffBamSubset data package for more details.}
\references{
  [1] Clouaire T et al (2012). Cfp1 integrates both CpG content and
  gene activity for accurate H3K4me3 deposition in embryonic stem cells.
  Genes Dev. August 1, 2012 26: 1714--1728
}
\keyword{datasets}

\seealso{
  \link[DiffBind]{dba},
  \link[DiffBind]{summary.DBA}
}
\examples{
  #The object has been generated using the following commands:
  ##### STEP1: create DBA object:
  
  library('MMDiffBamSubset')
  oldwd <- setwd(system.file("extdata", package="MMDiffBamSubset"))
  
  Cfp1 <- dba(sampleSheet="Cfp1.csv", minOverlap=3,
             config = data.frame(RunParallel=FALSE))
  
  ##### STEP2: compute histograms from bam files

  bin.length <- 50
  Peaks <- dba.peakset(Cfp1,bRetrieve=TRUE)
  Peaks <- Peaks[1:1000]
  Cfp1Profiles <- getPeakProfiles(Cfp1,Peaks,bin.length=bin.length,
         save.files=FALSE,run.parallel=FALSE)
  setwd(oldwd)
}

